@@ -381,7 +381,8 @@ def dirs_with_manifest(startdir: str):
         A directory that contains a manifest file of an Android project, None if
         no directory could be found
     """
-    for root, _dirs, files in os.walk(startdir):
+    for root, dirs, files in os.walk(startdir):
+        dirs.sort()
         if any(m in files for m in [
                 'AndroidManifest.xml', 'pom.xml', 'build.gradle', 'build.gradle.kts']):
             yield Path(root)
@@ -674,8 +675,6 @@ def checkupdates_app(app: metadata.App, auto: bool, commit: bool = False) -> Non
         if commit:
             logging.info("Commiting update for " + app.metadatapath)
             gitcmd = ["git", "commit", "-m", commitmsg]
-            if 'auto_author' in config:
-                gitcmd.extend(['--author', config['auto_author']])
             gitcmd.extend(["--", app.metadatapath])
             if subprocess.call(gitcmd) != 0:
                 raise FDroidException("Git commit failed")
@@ -725,7 +724,7 @@ def checkout_appid_branch(appid):
     try:
         git_repo.remotes.origin.fetch(f'{appid}:refs/remotes/origin/{appid}')
     except Exception as e:
-        logging.warning('"%s" branch not found on origin remote:\n\t%s', appid, e)
+        logging.debug('"%s" branch not found on origin remote:\n\t%s', appid, e)
     if appid in git_repo.remotes.origin.refs:
         start_point = f"origin/{appid}"
         for commit in git_repo.iter_commits(
@@ -750,7 +749,7 @@ def get_changes_versus_ref(git_repo, ref, f):
     return changes
 
 
-def push_commits(branch_name='checkupdates', verbose=False):
+def push_commits(branch_name='checkupdates'):
     """Make git branch then push commits as merge request.
 
     The appid is parsed from the actual file that was changed so that
@@ -770,6 +769,10 @@ def push_commits(branch_name='checkupdates', verbose=False):
     * https://docs.gitlab.com/ee/user/project/push_options.html
 
     """
+    if branch_name != "checkupdates":
+        if callable(getattr(git.SymbolicReference, "_check_ref_name_valid", None)):
+            git.SymbolicReference._check_ref_name_valid(branch_name)
+
     git_repo = git.Repo.init('.')
     upstream_main = get_upstream_main_branch(git_repo)
     files = set()
@@ -784,6 +787,10 @@ def push_commits(branch_name='checkupdates', verbose=False):
     if not files:
         return
 
+    # https://git-scm.com/docs/git-check-ref-format Git refname can't end with .lock
+    if branch_name.endswith(".lock"):
+        branch_name = f"{branch_name}_"
+
     remote = git_repo.remotes.origin
     if branch_name in remote.refs:
         if not get_changes_versus_ref(git_repo, f'origin/{branch_name}', files[0]):
@@ -807,21 +814,10 @@ def push_commits(branch_name='checkupdates', verbose=False):
     if current_version_only:
         push_options.append('merge_request.draft')
 
-    progress = None
-    if verbose:
-        import clint.textui
-
-        progress_bar = clint.textui.progress.Bar()
-
-        class MyProgressPrinter(git.RemoteProgress):
-            def update(self, op_code, current, maximum=None, message=None):
-                if isinstance(maximum, float):
-                    progress_bar.show(current, maximum)
-
-        progress = MyProgressPrinter()
+    progress = git.RemoteProgress()
 
     pushinfos = remote.push(
-        branch_name,
+        f"HEAD:refs/heads/{branch_name}",
         progress=progress,
         force=True,
         set_upstream=True,
@@ -829,22 +825,22 @@ def push_commits(branch_name='checkupdates', verbose=False):
     )
 
     for pushinfo in pushinfos:
+        logging.info(pushinfo.summary)
+        # Show potentially useful messages from git remote
+        if progress:
+            for line in progress.other_lines:
+                logging.info(line)
         if pushinfo.flags & (
             git.remote.PushInfo.ERROR
             | git.remote.PushInfo.REJECTED
             | git.remote.PushInfo.REMOTE_FAILURE
             | git.remote.PushInfo.REMOTE_REJECTED
         ):
-            # Show potentially useful messages from git remote
-            if progress:
-                for line in progress.other_lines:
-                    if line.startswith('remote:'):
-                        logging.debug(line)
             raise FDroidException(
                 f'{remote.url} push failed: {pushinfo.flags} {pushinfo.summary}'
             )
         else:
-            logging.debug(remote.url + ': ' + pushinfo.summary)
+            logging.info(remote.url + ': ' + pushinfo.summary)
 
 
 def prune_empty_appid_branches(git_repo=None, main_branch='main'):
@@ -954,7 +950,7 @@ def main():
             exit_code = 1
 
     if options.appid and options.merge_request:
-        push_commits(verbose=options.verbose)
+        push_commits()
         prune_empty_appid_branches()
 
     status_update_json(processed, failed)
