@@ -28,7 +28,6 @@ from .common import FDroidPopen
 from .exception import FDroidException
 
 config = None
-options = None
 start_timestamp = time.gmtime()
 
 
@@ -42,15 +41,14 @@ def status_update_json(signed):
 
 
 def main():
-
-    global config, options
+    global config
 
     # Parse command line...
     parser = ArgumentParser()
     common.setup_global_opts(parser)
-    options = parser.parse_args()
+    common.parse_args(parser)
 
-    config = common.read_config(options)
+    config = common.read_config()
 
     repodirs = ['repo']
     if config['archive_older'] != 0:
