@@ -29,7 +29,6 @@ from . import common
 from . import metadata
 
 config = None
-options = None
 
 
 def proper_format(app):
@@ -44,24 +43,45 @@ def proper_format(app):
     return content == cur_content
 
 
-def main():
+def remove_blank_flags_from_builds(builds):
+    """Remove unset entries from Builds so they are not written out."""
+    if not builds:
+        return list()
+    newbuilds = list()
+    for build in builds:
+        new = dict()
+        for k in metadata.build_flags:
+            v = build.get(k)
+            # 0 is valid value, it should not be stripped
+            if v is None or v is False or v == '' or v == dict() or v == list():
+                continue
+            new[k] = v
+        newbuilds.append(new)
+    return newbuilds
 
-    global config, options
+
+def main():
+    global config
 
     parser = ArgumentParser()
     common.setup_global_opts(parser)
-    parser.add_argument("-l", "--list", action="store_true", default=False,
-                        help=_("List files that would be reformatted (dry run)"))
-    parser.add_argument("appid", nargs='*', help=_("application ID of file to operate on"))
+    parser.add_argument(
+        "-l",
+        "--list",
+        action="store_true",
+        default=False,
+        help=_("List files that would be reformatted (dry run)"),
+    )
+    parser.add_argument(
+        "appid", nargs='*', help=_("application ID of file to operate on")
+    )
     metadata.add_metadata_arguments(parser)
-    options = parser.parse_args()
+    options = common.parse_args(parser)
     metadata.warnings_action = options.W
 
-    config = common.read_config(options)
+    config = common.read_config()
 
-    # Get all apps...
-    allapps = metadata.read_metadata(options.appid)
-    apps = common.read_app_args(options.appid, allapps, False)
+    apps = common.read_app_args(options.appid)
 
     for appid, app in apps.items():
         path = Path(app.metadatapath)
@@ -76,16 +96,10 @@ def main():
                 print(path)
             continue
 
-        newbuilds = []
-        for build in app.get('Builds', []):
-            new = metadata.Build()
-            for k in metadata.build_flags:
-                v = build[k]
-                if v is None or v is False or v == [] or v == '':
-                    continue
-                new[k] = v
-            newbuilds.append(new)
-        app['Builds'] = newbuilds
+        # TODO these should be moved to metadata.write_yaml()
+        builds = remove_blank_flags_from_builds(app.get('Builds'))
+        if builds:
+            app['Builds'] = builds
 
         # rewrite to temporary file before overwriting existing
         # file in case there's a bug in write_metadata
