@@ -11,7 +11,7 @@ from unittest import mock
 import git
 
 import fdroidserver
-from .testcommon import TmpCwd, mkdtemp, VerboseFalseOptions
+from .shared_test_code import TmpCwd, mkdtemp, VerboseFalseOptions
 
 basedir = Path(__file__).parent
 
@@ -326,6 +326,12 @@ class DeployTest(unittest.TestCase):
                         'repo/index.png',
                         '--exclude',
                         'repo/index.xml',
+                        '--exclude',
+                        'repo/signer-index.jar',
+                        '--exclude',
+                        'repo/signer-index.json',
+                        '--exclude',
+                        'repo/signer-index.json.asc',
                         'repo',
                         'example.com:/var/www/fdroid',
                     ],
@@ -413,6 +419,9 @@ class DeployTest(unittest.TestCase):
                         'repo/index.jar',
                         'repo/index.png',
                         'repo/index.xml',
+                        'repo/signer-index.jar',
+                        'repo/signer-index.json',
+                        'repo/signer-index.json.asc',
                         'example.com:/var/www/fdroid/repo/',
                     ],
                 )
@@ -729,6 +738,12 @@ class DeployTest(unittest.TestCase):
                         'repo/index.png',
                         '--exclude',
                         'repo/index.xml',
+                        '--exclude',
+                        'repo/signer-index.jar',
+                        '--exclude',
+                        'repo/signer-index.json',
+                        '--exclude',
+                        'repo/signer-index.json.asc',
                         '--no-check-md5',
                         '--skip-existing',
                         repo_section,
@@ -774,6 +789,12 @@ class DeployTest(unittest.TestCase):
                         'repo/index.png',
                         '--exclude',
                         'repo/index.xml',
+                        '--exclude',
+                        'repo/signer-index.jar',
+                        '--exclude',
+                        'repo/signer-index.json',
+                        '--exclude',
+                        'repo/signer-index.json.asc',
                         '--no-check-md5',
                         repo_section,
                         f"s3://{fdroidserver.deploy.config['awsbucket']}/fdroid/",
@@ -880,6 +901,12 @@ class DeployTest(unittest.TestCase):
                         'repo/index.png',
                         '--include',
                         'repo/index.xml',
+                        '--include',
+                        'repo/signer-index.jar',
+                        '--include',
+                        'repo/signer-index.json',
+                        '--include',
+                        'repo/signer-index.json.asc',
                         '--delete-removed',
                         '--delete-after',
                         '--no-check-md5',
