@@ -16,7 +16,7 @@ import shutil
 
 import fdroidserver
 from fdroidserver import common, index, publish, signindex, update
-from .testcommon import GP_FINGERPRINT, TmpCwd, mkdtemp
+from .shared_test_code import GP_FINGERPRINT, TmpCwd, mkdtemp
 
 
 basedir = Path(__file__).parent
@@ -38,8 +38,8 @@ class IndexTest(unittest.TestCase):
         cls.index_v1_jar = basedir / 'repo' / 'index-v1.jar'
 
     def setUp(self):
-        (basedir / 'config.py').chmod(0o600)
-        os.chdir(basedir)  # so read_config() can find config.py
+        (basedir / common.CONFIG_FILE).chmod(0o600)
+        os.chdir(basedir)  # so read_config() can find config.yml
 
         common.config = None
         common.options = Options
@@ -240,7 +240,7 @@ class IndexTest(unittest.TestCase):
         with self.assertRaises(fdroidserver.exception.VerificationException):
             data, _ignored = index.download_repo_index_v2(url)
 
-    def test_v1_sort_packages(self):
+    def test_sort_package_versions(self):
         i = [
             {
                 'packageName': 'org.smssecure.smssecure',
@@ -375,22 +375,19 @@ class IndexTest(unittest.TestCase):
                     "signer": "b33a601a9da97c82e6eb121eb6b90adab561f396602ec4dc8b0019fb587e2af6"
                 }
             }
-            os.makedirs('stats')
-            jarfile = 'stats/publishsigkeys.jar'
+            os.mkdir('repo')
+            jarfile = 'repo/signer-index.jar'
             with zipfile.ZipFile(jarfile, 'w', zipfile.ZIP_DEFLATED) as jar:
-                jar.writestr('publishsigkeys.json', json.dumps(sigkeyfps))
+                jar.writestr('signer-index.json', json.dumps(sigkeyfps))
             publish.sign_sig_key_fingerprint_list(jarfile)
-            with open('config.py', 'w'):
-                pass
+            common.write_config_file('')
 
-            index.v1_sort_packages(
-                i, common.load_stats_fdroid_signing_key_fingerprints()
-            )
+            index.sort_package_versions(i, common.load_publish_signer_fingerprints())
             self.maxDiff = None
             self.assertEqual(json.dumps(i, indent=2), json.dumps(o, indent=2))
 
             # and test it still works with get_first_signer_certificate
-            outdir = os.path.join(self.testdir, 'publishsigkeys')
+            outdir = os.path.join(self.testdir, 'index-signer-fingerprints')
             os.mkdir(outdir)
             common.apk_extract_signatures(jarfile, outdir)
             certs = glob.glob(os.path.join(outdir, '*.RSA'))
@@ -647,7 +644,7 @@ class IndexTest(unittest.TestCase):
             self.maxDiff = None
             self.assertEqual(css, pretty_css)
 
-    def test_v1_sort_packages_with_invalid(self):
+    def test_sort_package_versions_with_invalid(self):
         i = [
             {
                 'packageName': 'org.smssecure.smssecure',
@@ -657,7 +654,7 @@ class IndexTest(unittest.TestCase):
             }
         ]
 
-        index.v1_sort_packages(i, common.load_stats_fdroid_signing_key_fingerprints())
+        index.sort_package_versions(i, common.load_publish_signer_fingerprints())
 
     def test_package_metadata(self):
         """A smoke check and format check of index.package_metadata()"""
@@ -701,7 +698,7 @@ class IndexTest(unittest.TestCase):
         )
 
     def test_add_mirrors_to_repodict(self):
-        """Test based on the contents of tests/config.py"""
+        """Test based on the contents of tests/config.yml"""
         repodict = {'address': common.config['repo_url']}
         index.add_mirrors_to_repodict('repo', repodict)
         self.assertEqual(
@@ -718,7 +715,7 @@ class IndexTest(unittest.TestCase):
         os.chdir(self.testdir)
         repo_url = 'https://example.com/fdroid/repo'
         c = {'repo_url': repo_url, 'mirrors': ['http://one/fdroid']}
-        with open('config.yml', 'w') as fp:
+        with open(common.CONFIG_FILE, 'w', encoding='utf-8') as fp:
             yaml.dump(c, fp)
         common.config = None
         common.read_config()
@@ -815,6 +812,19 @@ class IndexTest(unittest.TestCase):
         with self.assertRaises(fdroidserver.exception.FDroidException):
             index.add_mirrors_to_repodict('repo', repodict)
 
+    def test_erroneous_isPrimary_in_mirrors_config(self):
+        """There can be only one primary mirror aka canonical URL"""
+        common.config = {
+            'repo_url': 'http://one/fdroid',
+            'mirrors': [
+                {'url': 'http://one/fdroid', 'countryCode': 'SA'},
+                {'url': 'http://two/fdroid', 'isPrimary': True},
+            ],
+        }
+        repodict = {'address': common.config['repo_url']}
+        with self.assertRaises(fdroidserver.exception.FDroidException):
+            index.add_mirrors_to_repodict('repo', repodict)
+
 
 class AltstoreIndexTest(unittest.TestCase):
     def test_make_altstore(self):
