@@ -74,6 +74,7 @@ class ScannerTest(unittest.TestCase):
             'com.jens.automation2': 3,
             'firebase-suspect': 1,
             'org.mozilla.rocket': 2,
+            'org.piepmeyer.gauguin': 1,
             'org.tasks': 3,
             'realm': 1,
             'se.manyver': 3,
@@ -107,12 +108,16 @@ class ScannerTest(unittest.TestCase):
             ('source-files/eu.siacs.conversations/build.gradle', 'free', 21),
             ('source-files/org.mozilla.rocket/app/build.gradle', 'focus', 40),
             ('source-files/com.jens.automation2/app/build.gradle', 'fdroidFlavor', 5),
+            ('source-files/flavor.test/build.gradle', ['foss', 'prod'], 7),
         ]
 
         for f, flavor, count in test_files:
             i = 0
             build = fdroidserver.metadata.Build()
-            build.gradle = [flavor]
+            if isinstance(flavor, list):
+                build.gradle = flavor
+            else:
+                build.gradle = [flavor]
             regexs = fdroidserver.scanner.get_gradle_compile_commands_without_catalog(
                 build
             )
@@ -350,6 +355,8 @@ class ScannerTest(unittest.TestCase):
                 with mock.patch(
                     'fdroidserver.common.get_apk_id',
                     return_value=(app.id, build.versionCode, build.versionName),
+                ), mock.patch(
+                    'fdroidserver.common.get_source_date_epoch', lambda f: '1234567890'
                 ):
                     with mock.patch(
                         'fdroidserver.common.is_debuggable_or_testOnly',
